pub struct SubscriptionPoller { /* private fields */ }Expand description
Subscription poller that consumes subscription data and delivers via a delivery trait.
Implementations
Sourceimpl SubscriptionPoller
impl SubscriptionPoller
Sourcepub fn new(batch_size: usize) -> Self
pub fn new(batch_size: usize) -> Self
Create a new subscription poller.
Arguments
batch_size- Maximum number of rows to read per subscription per poll cycle
Sourcepub fn register(&self, subscription_id: SubscriptionId)
pub fn register(&self, subscription_id: SubscriptionId)
Register a new subscription for polling.
Should be called when a client subscribes.
Sourcepub fn unregister(&self, subscription_id: &SubscriptionId)
pub fn unregister(&self, subscription_id: &SubscriptionId)
Unregister a subscription from polling.
Should be called when a client unsubscribes or disconnects.
Sourcepub fn poll_all(
&self,
engine: &StandardEngine,
system: &ActorSystem,
delivery: &dyn SubscriptionDelivery,
)
pub fn poll_all( &self, engine: &StandardEngine, system: &ActorSystem, delivery: &dyn SubscriptionDelivery, )
Poll all active subscriptions and deliver data via the delivery trait.
Sourcepub async fn run_loop(
self: Arc<Self>,
engine: StandardEngine,
system: ActorSystem,
delivery: Arc<dyn SubscriptionDelivery + Send + Sync>,
poll_interval: Duration,
stop_rx: Receiver<bool>,
)
pub async fn run_loop( self: Arc<Self>, engine: StandardEngine, system: ActorSystem, delivery: Arc<dyn SubscriptionDelivery + Send + Sync>, poll_interval: Duration, stop_rx: Receiver<bool>, )
Run the poller loop. Returns when the stop signal is received.