pub struct ConsumptionState {
pub db_subscription_id: SubscriptionId,
pub last_consumed_key: Option<EncodedKey>,
}Expand description
Consumption state for a single subscription.
Fields
db_subscription_id: SubscriptionIdThe database subscription ID being consumed
last_consumed_key: Option<EncodedKey>The last row key that was successfully consumed and deleted Used as a cursor for incremental polling